@@ -32,15 +32,21 @@ from cvxpy.problems.kktsolver import get_kktsolver
 import cvxpy.problems.iterative as iterative
 
 from collections import OrderedDict
+import warnings
 import itertools
 import numbers
 import cvxopt
 import cvxopt.solvers
 import ecos
-import scs
 import numpy as np
 import scipy.sparse as sp
 
+# Attempt to import SCS.
+try:
+    import scs
+except ImportError:
+    warnings.warn("The solver SCS could not be imported.")
+
 class Problem(u.Canonical):
     """A convex optimization problem.
 
