@@ -27,10 +27,11 @@ import cvxpy.interface.matrix_utilities as intf
 import cvxpy.settings as s
 from collections import deque
 import unittest
+from base_test import BaseTest
 from cvxopt import matrix
 import numpy as np
 
-class TestExpressions(unittest.TestCase):
+class TestExpressions(BaseTest):
     """ Unit tests for the expression/expression module. """
     def setUp(self):
         self.a = Variable(name='a')
@@ -134,16 +135,20 @@ class TestExpressions(unittest.TestCase):
         # Test the sign.
         c = Constant([[2], [2]])
         self.assertEqual(c.size, (1, 2))
+        self.assertEqual(c.sign, u.Sign.POSITIVE_KEY)
+        self.assertEqual((-c).sign, u.Sign.NEGATIVE_KEY)
+        self.assertEqual((0*c).sign, u.Sign.ZERO_KEY)
+        c = Constant([[2], [-2]])
         self.assertEqual(c.sign, u.Sign.UNKNOWN_KEY)
 
         # Test sign of a complex expression.
         c = Constant([1, 2])
         A = Constant([[1,1],[1,1]])
         exp = c.T*A*c
-        self.assertEqual(exp.sign, u.Sign.UNKNOWN_KEY)
-        self.assertEqual((c.T*c).sign, u.Sign.UNKNOWN_KEY)
+        self.assertEqual(exp.sign, u.Sign.POSITIVE_KEY)
+        self.assertEqual((c.T*c).sign, u.Sign.POSITIVE_KEY)
         exp = c.T.T
-        self.assertEqual(exp.sign, u.Sign.UNKNOWN_KEY)
+        self.assertEqual(exp.sign, u.Sign.POSITIVE_KEY)
         exp = c.T*self.A
         self.assertEqual(exp.sign, u.Sign.UNKNOWN_KEY)
 
@@ -462,3 +467,23 @@ class TestExpressions(unittest.TestCase):
         # self.assertEqual(exp.name(), "2 * a")
         self.assertEqual(exp.curvature, u.Curvature.AFFINE_KEY)
         self.assertEquals(exp.size, (1,1))
+
+    def test_neg_indices(self):
+        """Test negative indices.
+        """
+        c = Constant([[1,2],[3,4]])
+        exp = c[-1, -1]
+        self.assertEquals(exp.value, 4)
+        self.assertEquals(exp.size, (1, 1))
+        self.assertEquals(exp.curvature, u.Curvature.CONSTANT_KEY)
+
+        c = Constant([1,2,3,4])
+        exp = c[1:-1]
+        self.assertItemsAlmostEqual(exp.value, [2, 3])
+        self.assertEquals(exp.size, (2, 1))
+        self.assertEquals(exp.curvature, u.Curvature.CONSTANT_KEY)
+
+    def test_logical_indices(self):
+        """Test indexing with logical arrays.
+        """
+        pass
